@@ -310,6 +310,9 @@ CLOUDFORMATION_ACTIONS_ONLY_ACCEPTS_WILDCARD = [
     "ecs:ListTaskDefinitions",
     "ecs:PutAccountSetting",
     "ecs:PutAccountSettingDefault",
+    "eks:CreateCluster",
+    "eks:DescribeAddonVersions",
+    "eks:ListClusters",
     "elasticbeanstalk:CheckDNSAvailability",
     "elasticbeanstalk:CreateStorageLocation",
     "elasticbeanstalk:DescribeAccountAttributes",
