@@ -4,5 +4,6 @@ from cfripper.model.enums import RuleMode
 
 RULES_CONFIG = {
     "EC2SecurityGroupMissingEgressRule": RuleConfig(rule_mode=RuleMode.DISABLED),
-    "EC2SecurityGroupOpenToWorldRule": RuleConfig(filters=[firehose_ips_rules_config_filter]),
 }
+
+FILTERS = [firehose_ips_rules_config_filter]
